==> rc-ui-lib-1.3.4.tgz: package/es/notice-bar/NoticeBar.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { useRef, useEffect, useImperativeHandle, forwardRef, useContext } from 'react';
import classnames from 'classnames';
import Icon from '../icon';
import { getRect } from '../hooks/get-rect';
import useEventListener from '../hooks/use-event-listener';
import { isDef, noop } from '../utils';
import { raf, doubleRaf } from '../utils/raf';
import { useSetState, useUpdateEffect } from '../hooks';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
import PopupContext from '../popup/PopupContext';
var NoticeBar = /*#__PURE__*/forwardRef(function (props, ref) {
  var text = props.text,
      color = props.color,
      background = props.background,
      wrapable = props.wrapable,
      scrollable = props.scrollable,
      speed = props.speed,
      _props$delay = props.delay,
      delay = _props$delay === void 0 ? 1 : _props$delay;

  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var popupContext = useContext(PopupContext);

  var _createNamespace = createNamespace('notice-bar', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var _useSetState = useSetState({
    show: true,
    offset: 0,
    duration: 0
  }),
      _useSetState2 = _slicedToArray(_useSetState, 2),
      state = _useSetState2[0],
      setState = _useSetState2[1];

  var wrapRef = useRef();
  var contentRef = useRef();
  var wrapWidth = useRef(0);
  var contentWidth = useRef(0);
  var startTimer = useRef(null);

  var renderLeftIcon = function renderLeftIcon() {
    if (typeof props.leftIcon !== 'string' && /*#__PURE__*/React.isValidElement(props.leftIcon)) {
      return props.leftIcon;
    }

    if (props.leftIcon) {
      return /*#__PURE__*/React.createElement(Icon, {
        className: classnames(bem('left-icon')),
        name: props.leftIcon
      });
    }

    return null;
  };

  var getRightIconName = function getRightIconName() {
    if (props.mode === 'closeable') {
      return 'cross';
    }

    if (props.mode === 'link') {
      return 'arrow';
    }

    return '';
  };

  var onClickRightIcon = function onClickRightIcon(event) {
    if (props.mode === 'closeable') {
      setState({
        show: false
      });

      if (props.onClose) {
        props.onClose(event);
      }
    }
  }; //  右侧图标


  var renderRightIcon = function renderRightIcon() {
    if (props.rightIcon) {
      return props.rightIcon;
    }

    var name = getRightIconName();

    if (name) {
      return /*#__PURE__*/React.createElement(Icon, {
        name: name,
        className: classnames(bem('right-icon')),
        onClick: onClickRightIcon
      });
    }

    return null;
  }; //  动画结束


  var onTransitionEnd = function onTransitionEnd() {
    setState({
      offset: wrapWidth.current,
      duration: 0
    });
    raf(function () {
      // use double raf to ensure animation can start
      doubleRaf(function () {
        setState({
          offset: -contentWidth.current,
          duration: (contentWidth.current + wrapWidth.current) / speed
        });

        if (props.onReplay) {
          props.onReplay();
        }
      });
    });
  }; //  文字部分


  var renderMarquee = function renderMarquee() {
    var ellipsis = scrollable === false && !props.wrapable;
    var style = {
      transform: state.offset ? "translateX(".concat(state.offset, "px)") : '',
      transitionDuration: "".concat(state.duration, "s")
    };
    return /*#__PURE__*/React.createElement("div", {
      className: classnames(bem('wrap')),
      ref: wrapRef
    }, /*#__PURE__*/React.createElement("div", {
      className: classnames(bem('content'), {
        'rc-ellipsis': ellipsis
      }),
      ref: contentRef,
      style: style,
      onTransitionEnd: onTransitionEnd
    }, props.children || text));
  };

  var reset = function reset() {
    var ms = isDef(delay) ? +delay * 1000 : 0;
    wrapWidth.current = 0;
    contentWidth.current = 0;
    setState({
      offset: 0,
      duration: 0
    });
    clearTimeout(startTimer.current);
    startTimer.current = setTimeout(function () {
      if (!wrapRef.current || !contentRef.current || scrollable === false) {
        return;
      }

      var wrapRefWidth = getRect(wrapRef.current).width;
      var contentRefWidth = getRect(contentRef.current).width;

      if (scrollable || contentRefWidth > wrapRefWidth) {
        doubleRaf(function () {
          wrapWidth.current = wrapRefWidth;
          contentWidth.current = contentRefWidth;
          setState({
            offset: -contentWidth.current,
            duration: contentWidth.current / speed
          });
        });
      }
    }, ms);
  }; // fix cache issues with forwards and back history in safari
  // see: https://guwii.com/cache-issues-with-forwards-and-back-history-in-safari/


  useEventListener('pageshow', reset);
  useEffect(function () {
    reset();
  }, [text, scrollable]);
  useUpdateEffect(function () {
    reset();
  }, [popupContext.visible]);
  useImperativeHandle(ref, function () {
    return {
      reset: reset
    };
  });
  return state.show && /*#__PURE__*/React.createElement("div", {
    role: "alert",
    className: classnames(bem({
      wrapable: wrapable
    }), props.className),
    style: _objectSpread({
      color: color,
      background: background
    }, props.style),
    onClick: props.onClick
  }, renderLeftIcon(), renderMarquee(), renderRightIcon());
});
NoticeBar.defaultProps = {
  delay: 1,
  speed: 60,
  onClick: noop,
  onClose: noop
};
export default NoticeBar;

==> rc-ui-lib-1.3.5.tgz: package/es/notice-bar/NoticeBar.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React, { useRef, useEffect, useImperativeHandle, forwardRef, useContext } from 'react';
import classnames from 'classnames';
import Icon from '../icon';
import { getRect } from '../hooks/get-rect';
import useEventListener from '../hooks/use-event-listener';
import { isDef, noop } from '../utils';
import { raf, doubleRaf } from '../utils/raf';
import { useSetState, useUpdateEffect } from '../hooks';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
import PopupContext from '../popup/PopupContext';
var NoticeBar = /*#__PURE__*/forwardRef(function (props, ref) {
  var text = props.text,
    color = props.color,
    background = props.background,
    wrapable = props.wrapable,
    scrollable = props.scrollable,
    speed = props.speed,
    _props$delay = props.delay,
    delay = _props$delay === void 0 ? 1 : _props$delay;
  var _useContext = useContext(ConfigProviderContext),
    prefixCls = _useContext.prefixCls,
    createNamespace = _useContext.createNamespace;
  var popupContext = useContext(PopupContext);
  var _createNamespace = createNamespace('notice-bar', prefixCls),
    _createNamespace2 = _slicedToArray(_createNamespace, 1),
    bem = _createNamespace2[0];
  var _useSetState = useSetState({
      show: true,
      offset: 0,
      duration: 0
    }),
    _useSetState2 = _slicedToArray(_useSetState, 2),
    state = _useSetState2[0],
    setState = _useSetState2[1];
  var wrapRef = useRef();
  var contentRef = useRef();
  var wrapWidth = useRef(0);
  var contentWidth = useRef(0);
  var startTimer = useRef(null);
  var renderLeftIcon = function renderLeftIcon() {
    if (typeof props.leftIcon !== 'string' && /*#__PURE__*/React.isValidElement(props.leftIcon)) {
      return props.leftIcon;
    }
    if (props.leftIcon) {
      return /*#__PURE__*/React.createElement(Icon, {
        className: classnames(bem('left-icon')),
        name: props.leftIcon
      });
    }
    return null;
  };
  var getRightIconName = function getRightIconName() {
    if (props.mode === 'closeable') {
      return 'cross';
    }
    if (props.mode === 'link') {
      return 'arrow';
    }
    return '';
  };
  var onClickRightIcon = function onClickRightIcon(event) {
    if (props.mode === 'closeable') {
      setState({
        show: false
      });
      if (props.onClose) {
        props.onClose(event);
      }
    }
  };

  //  右侧图标
  var renderRightIcon = function renderRightIcon() {
    if (props.rightIcon) {
      return props.rightIcon;
    }
    var name = getRightIconName();
    if (name) {
      return /*#__PURE__*/React.createElement(Icon, {
        name: name,
        className: classnames(bem('right-icon')),
        onClick: onClickRightIcon
      });
    }
    return null;
  };

  //  动画结束
  var onTransitionEnd = function onTransitionEnd() {
    setState({
      offset: wrapWidth.current,
      duration: 0
    });
    raf(function () {
      // use double raf to ensure animation can start
      doubleRaf(function () {
        setState({
          offset: -contentWidth.current,
          duration: (contentWidth.current + wrapWidth.current) / speed
        });
        if (props.onReplay) {
          props.onReplay();
        }
      });
    });
  };

  //  文字部分
  var renderMarquee = function renderMarquee() {
    var ellipsis = scrollable === false && !props.wrapable;
    var style = {
      transform: state.offset ? "translateX(".concat(state.offset, "px)") : '',
      transitionDuration: "".concat(state.duration, "s")
    };
    return /*#__PURE__*/React.createElement("div", {
      className: classnames(bem('wrap')),
      ref: wrapRef
    }, /*#__PURE__*/React.createElement("div", {
      className: classnames(bem('content'), {
        'rc-ellipsis': ellipsis
      }),
      ref: contentRef,
      style: style,
      onTransitionEnd: onTransitionEnd
    }, props.children || text));
  };
  var reset = function reset() {
    var ms = isDef(delay) ? +delay * 1000 : 0;
    wrapWidth.current = 0;
    contentWidth.current = 0;
    setState({
      offset: 0,
      duration: 0
    });
    clearTimeout(startTimer.current);
    startTimer.current = setTimeout(function () {
      if (!wrapRef.current || !contentRef.current || scrollable === false) {
        return;
      }
      var wrapRefWidth = getRect(wrapRef.current).width;
      var contentRefWidth = getRect(contentRef.current).width;
      if (scrollable || contentRefWidth > wrapRefWidth) {
        doubleRaf(function () {
          wrapWidth.current = wrapRefWidth;
          contentWidth.current = contentRefWidth;
          setState({
            offset: -contentWidth.current,
            duration: contentWidth.current / speed
          });
        });
      }
    }, ms);
  };

  // fix cache issues with forwards and back history in safari
  // see: https://guwii.com/cache-issues-with-forwards-and-back-history-in-safari/
  useEventListener('pageshow', reset);
  useEffect(function () {
    reset();
  }, [text, scrollable]);
  useUpdateEffect(function () {
    reset();
  }, [popupContext.visible]);
  useImperativeHandle(ref, function () {
    return {
      reset: reset
    };
  });
  return state.show && /*#__PURE__*/React.createElement("div", {
    role: "alert",
    className: classnames(bem({
      wrapable: wrapable
    }), props.className),
    style: _objectSpread({
      color: color,
      background: background
    }, props.style),
    onClick: props.onClick
  }, renderLeftIcon(), renderMarquee(), renderRightIcon());
});
NoticeBar.defaultProps = {
  delay: 1,
  speed: 60,
  onClick: noop,
  onClose: noop
};
export default NoticeBar;
